==> kdelibs-1.90.tar.bz2: kdelibs-1.90/dcop/dcopglobal.h <==
/*
   Copyright (c) 1999 Preston Brown <pbrown@kde.org>
   Copyright (c) 1999 Matthias Ettrich <ettrich@kde.org>

   Permission is hereby granted, free of charge, to any person obtaining a copy
   of this software and associated documentation files (the "Software"), to deal
   in the Software without restriction, including without limitation the rights
   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
   copies of the Software, and to permit persons to whom the Software is
   furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
   AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
   AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#ifndef DCOPGLOBAL_H
#define DCOPGLOBAL_H "$Id: dcopglobal.h,v 1.14 2000/05/08 18:25:59 ettrich Exp $"

#define DCOPVendorString "KDE"
#define DCOPReleaseString "1.1"
#define DCOPVersionMajor 1
#define DCOPVersionMinor 1

#define DCOPSend 1
#define DCOPCall 2
#define DCOPReply 3
#define DCOPReplyFailed 4
#define DCOPReplyWait 5
#define DCOPReplyDelayed 6
#define DCOPCallRejected 7

/**
 * DCOP Protocol description
 * ================
 *
 *
 * A DCOPSend message does not expect any reply.
 * data: << fromId << toId << objId << fun << dataSize + data[dataSize]
 *
 * A DCOPCall message can get a DCOPReply, a DCOPReplyFailed
 * or a DCOPReplyWait message in response.
 * data: << fromId << toId << objId << fun << dataSize + data[dataSize]
 *
 * DCOPReply is the successfull reply to a DCOPCall message
 * data: << replyType << replyDataSize + replyData[replyDataSize]
 *
 * DCOPReplyFailed indicates failure of a DCOPCall message
 * data:
 *
 * DCOPReplyWait indicates that a DCOPCall message is succesfully
 * being processed but that response will come later.
 * data: << transactionId
 *
 * DCOPReplyDelayed is the successfull reply to a DCOPCall message
 * after a DCOPReplyWait message.
 * data: << fromId << toId << transactionId << replyType << replyData
 *
 * All c-strings (fromId, toId, objId, fun and replyType), are marshalled with
 * their respective  length as 32 bit unsigned integer first:
 * data: length + string[length]
 * Note: This happens automatically when using QCString on a
 * QDataStream.
 *
 */

int DCOPAuthCount = 1;
const char *DCOPAuthNames[] = {"MIT-MAGIC-COOKIE-1"};
extern "C" {
extern IcePoAuthStatus _IcePoMagicCookie1Proc (_IceConn *, void **, int, int, int, void *, int *, void **, char **);
extern IcePaAuthStatus _IcePaMagicCookie1Proc (_IceConn *, void **, int, int, void *, int *, void **, char **);
}
IcePoAuthProc DCOPClientAuthProcs[] = {_IcePoMagicCookie1Proc};
IcePaAuthProc DCOPServerAuthProcs[] = {_IcePaMagicCookie1Proc};

/**
 * @internal
 */
struct DCOPMsg {
  CARD8 majorOpcode;
  CARD8 minorOpcode;
  CARD8 data[2];
  CARD32 length B32;
  CARD32 time;
};

#endif

==> kdelibs-1.91.tar.bz2: kdelibs-1.91/dcop/dcopglobal.h <==
/*
   Copyright (c) 1999 Preston Brown <pbrown@kde.org>
   Copyright (c) 1999 Matthias Ettrich <ettrich@kde.org>

   Permission is hereby granted, free of charge, to any person obtaining a copy
   of this software and associated documentation files (the "Software"), to deal
   in the Software without restriction, including without limitation the rights
   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
   copies of the Software, and to permit persons to whom the Software is
   furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
   AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
   AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#ifndef DCOPGLOBAL_H
#define DCOPGLOBAL_H "$Id: dcopglobal.h,v 1.18 2000/06/05 18:08:16 waba Exp $"

#define DCOPVendorString "KDE"
#define DCOPReleaseString "1.1"
#define DCOPVersionMajor 1
#define DCOPVersionMinor 1

#define DCOPSend 1
#define DCOPCall 2
#define DCOPReply 3
#define DCOPReplyFailed 4
#define DCOPReplyWait 5
#define DCOPReplyDelayed 6
#define DCOPCallRejected 7
#define DCOPFind 8

/**
 * DCOP Protocol description
 * ================
 *
 *
 * A DCOPSend message does not expect any reply.
 * data: << fromId << toId << objId << fun << dataSize + data[dataSize]
 *
 * A DCOPCall message can get a DCOPReply, a DCOPReplyFailed
 * or a DCOPReplyWait message in response.
 * data: << fromId << toId << objId << fun << dataSize + data[dataSize]
 *
 * DCOPReply is the successfull reply to a DCOPCall message
 * data: << replyType << replyDataSize + replyData[replyDataSize]
 *
 * DCOPReplyFailed indicates failure of a DCOPCall message
 * data:
 *
 * DCOPReplyWait indicates that a DCOPCall message is succesfully
 * being processed but that response will come later.
 * data: << transactionId
 *
 * DCOPReplyDelayed is the successfull reply to a DCOPCall message
 * after a DCOPReplyWait message.
 * data: << fromId << toId << transactionId << replyType << replyData
 *
 * DCOPFind is a message much like a "call" message. It can however
 * be send to multiple objects within a client. If a function in a 
 * object that is being called returns a boolean with the value "true",
 * a DCOPReply will be send back containing the DCOPRef of the object 
 * who returned "true".
 *
 * All c-strings (fromId, toId, objId, fun and replyType), are marshalled with
 * their respective  length as 32 bit unsigned integer first:
 * data: length + string[length]
 * Note: This happens automatically when using QCString on a
 * QDataStream.
 *
 */

int DCOPAuthCount = 1;
const char *DCOPAuthNames[] = {"MIT-MAGIC-COOKIE-1"};
#ifdef __cplusplus
extern "C" {
#endif
extern IcePoAuthStatus _IcePoMagicCookie1Proc (IceConn, void **, int, int, int, void *, int *, void **, char **);
extern IcePaAuthStatus _IcePaMagicCookie1Proc (IceConn, void **, int, int, void *, int *, void **, char **);
#ifdef __cplusplus
}
#endif
IcePoAuthProc DCOPClientAuthProcs[] = {_IcePoMagicCookie1Proc};
IcePaAuthProc DCOPServerAuthProcs[] = {_IcePaMagicCookie1Proc};

/**
 * @internal
 */
struct DCOPMsg {
  CARD8 majorOpcode;
  CARD8 minorOpcode;
  CARD8 data[2];
  CARD32 length B32;
  CARD32 time;
};

#endif
